************************************************************************************************************
*WEIGHTS
*prepare.data.do
*uses OHS, LFS and GHS data
*merges necessary files and creates consistent variables used in entropy program
*saves reduced versions of data in $general\temp.dta with consistent names
************************************************************************************************************
clear
cap set mem 600m
set more off

*filepaths
cd e:\
global ghsfiles "\SALDRU_210409\General Household Survey"
global ohsfiles "\SALDRU_210409\October Household Survey 1993-99"
global lfsfiles "\SALDRU_210409\labour force survey 2000-"
global general="\SALDRU_210409\WEIGHTS"
global tempfiles="\SALDRU_210409\WEIGHTS\temp.dta" 
************************************************************************************************************
***OHS 1993--incomplete!
/*
use "$ohsfiles\Diego\1993\STATA\persons.dta", clear
destring *, replace
*2 cases where  uniqnum is missing, other information is not missing (all from the transvaal)
rename  UNIQ_NUM uniqnum
rename  PERSON person
drop if  uniqnum==.
isid  uniqnum person

drop weight /* household weight has the same name in the household */
sort uniqnum 
***this file has no household identifier!
merge uniqnum using "$ohsfiles\Diego\1993\STATA\house.dta"
*no unique id in the household file
isid  HHID PPERSNO
assert _m==3
numlabel, add

rename HHID uqnr
rename PPERSNO personnr
rename  PAGE age
*no missing category
rename PGENDER sex
replace sex=. if sex>2
rename PRACE1 race
replace race=. if race>4
rename PROV province
rename  HHWGT hhweight

keep uqnr personnr age sex race province hhweight
save "$tempfiles\ohs1993.dta", replace

*/

***OHS 1994
use "$ohsfiles\Diego\1994\STATA\Person", clear
isid  UQNR PERSNO
rename WEIGHT perswgt
preserve
use "$ohsfiles\Diego\1994\STATA\House",clear
sort UQNR
save "$ohsfiles\Diego\1994\STATA\House",replace
restore
sort UQNR 
merge UQNR using "$ohsfiles\Diego\1994\STATA\House"
isid  UQNR PERSNO
assert _m==3
numlabel, add

*no missing category
rename UQNR uqnr
rename PERSNO personnr
rename PROV province
rename GENDER sex
rename AGE age
*different race codes
recode POPGRP (1=3) (3=4) (4=1), gen(race)
rename WEIGHT hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\ohs1994.dta", replace


***OHS 1995
*note that the original data results in a small total population in the household weight is used -the rewieghted data is better
use "$ohsfiles\OHS 1995\Data\Original Data\Stata\OHS 1995 Person", clear
isid  HHID persno
rename weight perswgt
replace perswgt=perswgt/1000
sort HHID 
merge HHID using "$ohsfiles\OHS 1995\Data\Original Data\Stata\OHS 1995 House.dta"
isid  HHID persno
assert _m==3
numlabel, add
rename HHID uqnr
rename persno personnr
*no missing category
rename gender sex
replace sex=. if sex>2
rename pop_grp race
replace race=. if race>4
gen hhweight=weight/1000
keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\ohs1995.dta", replace

/*this is the reweighted data

use "$ohsfiles\OHS 1995\Data\Reweighted Data\Stata\OHS 1995 Person_1996 Weights.dta", clear
isid  hhid  PERSNO
drop NEWWGT /* household weight also called weight*/
sort hhid 
merge hhid using "$ohsfiles\OHS 1995\Data\Reweighted Data\Stata\OHS 1995 House_1996 Weights.dta"
isid  hhid  PERSNO
assert _m==3
numlabel, add
destring, replace

rename hhid uqnr
rename PERSNO personnr
*no missing category
rename AGE age 
rename GENDER sex
replace sex=. if sex>2
rename pop_grp race
replace race=. if race>4
rename  NEWWGT1 hhweight

keep uqnr personnr age sex race province hhweight
save "$tempfiles\ohs1995.dta", replace
*/

***OHS 1996-incomplete/problematic
/*
use "$ohsfiles\Diego\1996\STATA\Person", clear
isid  MDNUMBER EANUMBER VPNUMBER RESPONNO
sort MDNUMBER EANUMBER VPNUMBER 
preserve
use "$ohsfiles\Diego\1996\STATA\House.dta", clear
sort MDNUMBER EANUMBER VPNUMBER 
save "$ohsfiles\Diego\1996\STATA\House.dta", replace
restore
***MDNUMBER EANUMBER VPNUMBER is not unique within households!***
merge MDNUMBER EANUMBER VPNUMBER using "$ohsfiles\Diego\1996\STATA\House.dta"
*individuals without households!
drop if _m==1
assert _m==3
isid MDNUMBER EANUMBER VPNUMBER
numlabel, add

rename UQNR uqnr
rename PERSNO personnr
rename  AGE age
*no missing category
rename GENDER sex
replace sex=. if sex>2
rename POPGRP race
replace race=. if race>4
rename PROV province
rename  WEIGHT hhweight

keep uqnr personnr age sex race province hhweight
save "$tempfiles\ohs1996.dta", replace
*/

***OHS 1997
use "$ohsfiles\OHS 1997\Data\Stata\OHS 1997 Person.dta", clear
isid  HHID PPERSNO
rename  PERSWGT perswgt
sort HHID 
merge HHID using "$ohsfiles\OHS 1997\Data\Stata\OHS 1997 House.dta"
isid  HHID PPERSNO
assert _m==3
numlabel, add

rename HHID uqnr
rename PPERSNO personnr
rename  PAGE age
*no missing category
rename PGENDER sex
replace sex=. if sex>2
rename PRACE1 race
replace race=. if race>4
rename PROV province
rename  HHWGT hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\ohs1997.dta", replace


***OHS 1998
use "$ohsfiles\Diego\1998\STATA\Persons.dta", clear
isid UQNR PERSONNR
rename WGT perswgt
replace perswgt=perswgt/10000
sort UQNR 
preserve
use "$ohsfiles\Diego\1998\STATA\House.dta", clear
sort UQNR
save "$ohsfiles\Diego\1998\STATA\House.dta", replace
restore
merge UQNR using "$ohsfiles\Diego\1998\STATA\House.dta"
isid  UQNR PERSONNR
assert _m==3
numlabel, add

rename UQNR uqnr
destring uqnr, replace
format uqnr %15.0f
rename PERSONNR personnr
rename  C_AGE age
*no missing category
rename B_GENDER sex
destring sex D_RACE age, replace
replace sex=. if sex>2
rename D_RACE race
replace race=. if race>4
rename PROV province
rename  WGT hhweight
replace hhweight=hhweight/10000
keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\ohs1998.dta", replace


***OHS 1999
use "$ohsfiles\OHS 1999\Data\Stata\OHS 1999 Person.dta", clear
isid  UQNR PERSONNR
rename  WEIGHT perswgt
sort UQNR 
merge UQNR using "$ohsfiles\OHS 1999\Data\Stata\OHS 1999 House.dta", 
isid  UQNR PERSONNR
assert _m==3
numlabel, add

rename UQNR uqnr
rename PERSONNR personnr
destring uqnr personnr, replace
rename  C1_AGE age
replace age="" if age=="***"
destring age, replace
rename B_GENDER sex
replace sex="" if sex=="*"
destring sex, replace
rename D_RACE race
replace race="" if race=="*"
destring race, replace
rename PROV province
destring province , replace
rename  HHWGT hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\ohs1999.dta", replace


***LFS2000
/*have run this but used the person weight instead of the household weight
*no household level file and person weight not common within household
use "$lfsfiles\LFS 2000 Feb\Data\STATA\lfs 2000_1 Person.dta", clear
isid UqNr PersonNr
numlabel, add

**need province and weight from household file, age, sex and race from individual

rename UqNr uqnr
rename PersonNr personnr
rename E_Age_Feb2000 age
replace age=. if age==999
rename D_Gender_Feb2000 sex
replace sex =. if sex==9
rename F_Race_Feb2000 race
replace race=. if race>4
rename Prov_Feb2000 province
*rename HWgt_Sep2000 hhweight
rename Wgt_Feb2000 perswgt


keep uqnr personnr age sex race province perswgt
save "$tempfiles\lfs2_2000.dta", replace
*/

*note that the original data has problems - 127 individuals without households, hence have used the reweighted data
use "$lfsfiles\lfs 2000 sept reweighted\data\stata\lfs 2000 _2 Person_rw.dta", clear
isid UqNr PersonNr
rename  PWgt_Sep2000 perswgt
sort UqNr 
merge UqNr using "$lfsfiles\lfs 2000 sept reweighted\data\stata\LFS 2000 _2 House_rw.dta"
assert _m==3
isid UqNr PersonNr
numlabel, add


rename UqNr uqnr
rename PersonNr personnr
rename D_Age_Sep2000 age
replace age=. if age==999
rename C_Gender_Sep2000 sex
replace sex =. if sex==9
rename E_Race_Sep2000 race
replace race=. if race>4
rename Prov_Sep2000 province
rename HWgt_Sep2000 hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2000.dta", replace

***LFS 2001 - incomplete/problem
use "$lfsfiles\newdownloadfromlynn\LFS 2001 Feb\Data\STATA\lfs 2001_1 Person.dta", clear
isid UqNr  PersonNr
rename  NewWgt2_Feb2001 perswgt
sort UqNr 
merge UqNr using "$lfsfiles\newdownloadfromlynn\LFS 2001 Feb\Data\STATA\lfs 2001_1 House.dta"
*13 households without individual information
*isid UqNr  PersonNr
*assert _m==3
drop if _m<3
numlabel, add

rename UqNr uqnr
rename PersonNr personnr
rename D_Age_Feb2001 age
replace age=. if age==999
rename C_Gender_Feb2001 sex
replace sex =. if sex==9
rename E_Race_Feb2001 race
replace race=. if race>4
rename Prov_Feb2001 province
rename HWgt_Feb2001 hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs2_2001.dta", replace

*incomplete/problem
*these are not the reweighted files 
use "$lfsfiles\newdownloadfromlynn\LFS 2001 Sept_w New Weights\data\stata\lfs 2001_2 Person.dta", clear
isid UqNr  PersonNr
rename  Pondfin_imp_trim_Sep2001 perswgt
sort UqNr 
merge UqNr using "$lfsfiles\newdownloadfromlynn\LFS 2001 Sept_w New Weights\data\stata\lfs 2001_2 House.dta"
*isid UqNr  PersonNr
*assert _m==3
*5 individuals without households and 16 households without individuals
drop if _m<3
numlabel, add

rename UqNr uqnr
rename PersonNr personnr
rename D_Age_Sep2001 age
replace age=. if age==999
rename C_Gender_Sep2001 sex
replace sex =. if sex==9
rename E_Race_Sep2001 race
replace race=. if race>4
rename Prov_Sep2001 province
rename weight_Sep2001 hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2001.dta", replace

***LFS 2002 -incomplete
*no household level file
**person weight is not common within household
use "$lfsfiles\LFS 2002 Feb\Data\STATA\lfs 2002_1 Person.dta", clear
*egen max=max(Perswgt_Feb2002), by(UqNr)
*assert max==Perswgt_Feb2002
isid UqNr  PersonNr
numlabel, add

rename UqNr uqnr
rename PersonNr personnr
rename D_Age_Feb2002 age
replace age=. if age==999
rename C_Gender_Feb2002 sex 
replace sex =. if sex ==9
gen female=(sex ==2) if sex !=.
rename E_Race_Feb2002 race 
replace race =. if race >4
rename Prov_Feb2002 province
rename Perswgt_Feb2002 hhweight
gen perswgt=hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs2_2002.dta", replace

*incomplete/problem
use "$lfsfiles\newdownloadfromlynn\LFS 2002 Sept_w New Weights\data\stata\lfs 2002_2 Person.dta", clear
isid UqNr  PersonNr
rename  person_wgt_Sep2002 perswgt
sort UqNr  
merge UqNr using "$lfsfiles\newdownloadfromlynn\LFS 2002 Sept_w New Weights\data\stata\lfs 2002_2 House.dta"
**55 households without individual questionnaires
*isid UqNr  PersonNr
*assert _m==3
drop if _m<3
numlabel, add

rename UqNr uqnr
rename PersonNr personnr
rename D_Age_Sep2002 age
replace age=. if age==999
rename C_Gender_Sep2002 sex 
replace sex =. if sex ==9
gen female=(sex ==2) if sex !=.
rename E_Race_Sep2002 race 
replace race =. if race >4
rename Prov_Sep2002 province
rename hhweight_Sep2002 hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2002.dta", replace

***LFS 2003
*no household file but person weight common within household
use "$lfsfiles\LFS 2003 Mar\Data\STATA\lfs 2003_1 Person.dta", clear
isid UqNr  PersonNr
sort UqNr  

rename UqNr uqnr
rename PersonNr personnr
rename Age_Mar2003 age
replace age=. if age==999
rename Gender_Mar2003 sex 
replace sex =. if sex ==9
rename Popgrp_Mar2003 race 
replace race =. if race >4
rename Prov_Mar2003 province
rename  Personwgt_Mar2003 hhweight
gen perswgt=hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs3_2003.dta", replace


use "$lfsfiles\newdownloadfromlynn\LFS 2003 Sept_w New Weights\data\stata\lfs 2003_2 Person.dta", clear
isid UqNr  PersonNr
rename  Pers_Wgt_Sep2003 perswgt
sort UqNr  
merge UqNr using "$lfsfiles\newdownloadfromlynn\LFS 2003 Sept_w New Weights\data\stata\lfs 2003_2 House.dta"
tab _m
*ten households without individual questionnaires
drop if _m<3
isid UqNr  PersonNr
numlabel, add

rename UqNr uqnr
rename PersonNr personnr
rename Age_Sep2003 age
replace age=. if age==999
rename Gender_Sep2003 sex 
replace sex =. if sex ==9
rename Popgrp_Sep2003 race 
replace race =. if race >4
rename Prov_Sep2003 province
rename House_wgt_Sep2003 hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2003.dta", replace

***LFS 2004
use "$lfsfiles\LFS 2004 Mar\Data\STATA\lfs 2004_1 Person.dta", clear
isid UqNr  PersonNr
rename Pers_wgt perswgt
sort UqNr 
merge UqNr using "$lfsfiles\LFS 2004 Mar\Data\STATA\lfs 2004_1 House.dta"
isid UqNr  PersonNr
assert _m==3
numlabel, add

rename UqNr uqnr
rename PersonNr personnr
rename Age age
replace age=. if age==999
rename  C_Gender sex
replace sex =. if sex ==9
rename E_race race
replace race =. if race >4
rename Prov province
rename House_Wgt hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs3_2004.dta", replace



use "$lfsfiles\LFS 2004 Sept\data\stata\lfs 2004_2 Person.dta", clear
isid uqnr  personnr
rename  person_wgt perswgt
sort uqnr 
merge uqnr using "$lfsfiles\LFS 2004 Sept\data\stata\lfs 2004_2 House.dta"
isid uqnr  personnr
assert _m==3
numlabel, add

replace age=. if age==999
rename gender sex
replace sex =. if sex ==9
rename popgrp race
replace race =. if race >4
rename prov province
rename house_wgt hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2004.dta", replace


***LFS 2005

use "$lfsfiles\LFS 2005 Mar\Data\STATA\lfs 2005_1 Person.dta", clear
isid uqnr  personnr
rename  person_wgt perswgt
sort uqnr 
merge uqnr using "$lfsfiles\LFS 2005 Mar\Data\STATA\lfs 2005_1 House.dta"
isid uqnr  personnr
assert _m==3
numlabel, add

replace age=. if age==999
rename gender sex
replace sex =. if sex ==9
rename popgrp race
replace race =. if race >4
rename house_wgt hhweight
rename prov province

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs3_2005.dta", replace

*person weights common within household so use as a household weight
use "$lfsfiles\LFS 2005 Sept_w New Weights\data\stata\lfs 2005_2 Person.dta", clear
isid uqnr  personnr
numlabel, add

replace age=. if age==999
rename gender sex
replace sex =. if sex ==9
rename popgrp race
replace race =. if race >4
rename pers_wgt hhweight
gen perswgt=hhweight
rename prov province

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2005.dta", replace

***LFS 2006
use "$lfsfiles\LFS 2006 Mar\Data\STATA\LFS 2006_1 Person.dta", clear
rename  UqNr uqnr
rename PersonNr personnr
isid uqnr  personnr
numlabel, add

rename  Age age
rename  Gender sex
rename  Popgrp race
replace age=. if age==999
replace sex =. if sex ==9
replace race =. if race >4
rename Prov province
rename person_wgt hhweight
gen perswgt=hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs3_2006.dta", replace

use "$lfsfiles\LFS 2006 Sept\data\stata\LFS_2 2006 Person.dta", clear
isid uqnr  personnr
numlabel, add

replace age=. if age==999
rename gender sex
replace sex =. if sex ==9
rename popgrp race
replace race =. if race >4
rename prov province
rename person_wgt hhweight
gen perswgt=hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2006.dta", replace

***LFS 2007
use "$lfsfiles\newdownloadfromlynn\LFS 2007 Mar\Data\STATA\lfs 2007_1 Person.dta", clear
*isid uqnr  personnr
*10 duplicates !!
numlabel, add

replace age=. if age==999
rename gender sex
replace sex =. if sex ==9
rename popgrp race
replace race =. if race >4
rename prov province
rename person_wgt hhweight
gen perswgt=hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs3_2007.dta", replace

use "$lfsfiles\LFS 2007 Sept V2\data\stata\lfs 2007_2 Person.dta", clear
isid uqnr  personnr
numlabel, add

replace age=. if age==999
rename gender sex
replace sex =. if sex ==9
rename popgrp race
replace race =. if race >4
rename prov province
rename person_wgt hhweight
gen perswgt=hhweight

keep uqnr personnr age sex race province hhweight perswgt
save "$tempfiles\lfs9_2007.dta", replace


****GHS****
**2002
use "$ghsfiles\GHS 2002\Data\STATA\GHS 2002 Person.dta", clear
isid  UqNr PersonNr
rename  Person_Wgt perswgt
sort UqNr
merge UqNr using "$ghsfiles\GHS 2002\Data\STATA\GHS 2002 Hhold.dta"
isid  UqNr PersonNr
assert _m==3

rename UqNr uqnr
rename PersonNr personnr
rename  C_Gender sex
replace sex=. if sex>2
rename  D_Age age
replace age=. if age==999
rename  E_Race race
replace race=. if race>4
rename Prov province 
rename house_Wgt hhweight

**save data
keep uqnr personnr age sex race province hhweight perswgt
save $tempfiles\ghs2002.dta, replace

**2003
use "$ghsfiles\GHS 2003\Data\STATA\GHS 2003 Person.dta", clear
isid  UqNr PersonNr
rename  Perswgt perswgt
sort UqNr
merge UqNr using "$ghsfiles\GHS 2003\Data\STATA\GHS 2003 Hhold.dta"
isid  UqNr PersonNr
assert _m==3

rename UqNr uqnr
rename PersonNr personnr
rename  Gender sex
replace sex=. if sex>2
rename  Age age
replace age=. if age==999
rename  Popgrp race
replace race=. if race>4
rename Prov province 
rename  Housewgt hhweight

**save data
keep uqnr personnr age sex race province hhweight perswgt
save $tempfiles\ghs2003.dta, replace

**2004
use "$ghsfiles\GHS 2004\Data\STATA\GHS 2004 Person.dta", clear
isid   uqnr personnr
rename  pers_wgt perswgt
sort uqnr
merge uqnr using "$ghsfiles\GHS 2004\Data\STATA\GHS 2004 Hhold.dta"
isid   uqnr personnr
assert _m==3

rename  gender sex
replace sex=. if sex>2
replace age=. if age==999
rename  popgrp race
replace race=. if race>4
rename prov province 
rename   house_wgt hhweight

**save data
keep uqnr personnr age sex race province hhweight perswgt
save $tempfiles\ghs2004.dta, replace


**2005
use "$ghsfiles\GHS 2005\Data\STATA\GHS 2005 Person.dta", clear
isid   uqnr personnr
rename  person_wgt perswgt
sort uqnr
merge uqnr using "$ghsfiles\GHS 2005\Data\STATA\GHS 2005 Hhold.dta"
isid   uqnr personnr
assert _m==3

rename  gender sex
replace sex=. if sex>2
replace age=. if age==999
rename  popgrp race
replace race=. if race>4
rename prov province 
rename house_wgt hhweight

**save data
keep uqnr personnr age sex race province hhweight perswgt
save $tempfiles\ghs2005.dta, replace

**2006
use "$ghsfiles\GHS 2006\Data\STATA\GHS 2006 Person.dta", clear
isid   uqnr personnr
rename  pers_wgt perswgt
sort uqnr
merge uqnr using "$ghsfiles\GHS 2006\Data\STATA\GHS 2006 House.dta"
isid   uqnr personnr
assert _m==3

rename  gender sex
replace sex=. if sex>2
replace age=. if age==999
rename  popgrp race
replace race=. if race>4
rename prov province 
rename house_wgt hhweight

**save data
keep uqnr personnr age sex race province hhweight perswgt
save $tempfiles\ghs2006.dta, replace

**2007
use "$ghsfiles\GHS 2007\Data\STATA\GHS 2007 Person.dta", clear
isid   uqnr personnr
rename  person_wgt perswgt
sort uqnr
merge uqnr using "$ghsfiles\GHS 2007\Data\STATA\GHS 2007 House.dta"
isid   uqnr personnr
assert _m==3

rename  gender sex
replace sex=. if sex>2
replace age=. if age==999
rename  popgrp race
replace race=. if race>4
rename prov province 
rename house_wgt hhweight

**save data
keep uqnr personnr age sex race province hhweight perswgt
save $tempfiles\ghs2007.dta, replace


**end of prepare.data.do file
