*Created by Nicola Branson, SALDRU, University of Cape Town. Email: nicola.branson@uct.ac.za

** WEIGHTS
*** weights.ghs.do
*** File to create GHS 2002-2007 cross-entropy weights. 
*** Requires the following files:
*** y.dta								This contains the constraint vector
*** ghs200`x'_`y'.dta					Which contains uqnr personnr hhweight perswgt province sex race and age  
************************************************************************************************************************
version 10
clear
cap set mem 300m
set more off
cap log close
*filepaths
cd e:\
global ghsfiles "\SALDRU_210409\General Household Survey"
global ohsfiles "\SALDRU_210409\October Household Survey 1993-99"
global lfsfiles "\SALDRU_210409\labour force survey 2000-"
global general="\SALDRU_210409\WEIGHTS"
global tempfiles="\SALDRU_210409\WEIGHTS\temp.dta" 
************************************************************************************************************************
forvalues x=2/7{
use "$tempfiles\y.dta", clear  /*must contain y and total`x' (scalar)*/
drop if cell=="LM" 
count
assert _N==144
keep y6_200`x'
rename y6_200`x' y200`x'
mkmat y200`x'
use  "$tempfiles\ghs200`x'.dta", clear
keep uqnr   personnr  hhweight  province  sex  race  age 
order uqnr   personnr  hhweight  province  sex  race  age  

*create province dummies
tab province  , gen(P)

*reference category
drop P9

*race, sex and age dummies
gen byte A=(race==1)
gen byte C=(race==2)
gen byte I=(race==3)
gen byte W=(race==4)
gen byte M=sex==1
gen byte F=sex==2

gen byte a_0=age>=0& age <=4
gen byte a_5=age>=5& age <=9
gen byte a10=age>=10& age <=14
gen byte a15=age>=15& age <=19
gen byte a20=age>=20& age <=24
gen byte a25=age>=25& age <=29
gen byte a30=age>=30& age <=34
gen byte a35=age>=35& age <=39
gen byte a40=age>=40& age <=44
gen byte a45=age>=45& age <=49
gen byte a50=age>=50& age <=54
gen byte a55=age>=55& age <=59
gen byte a60=age>=60& age <=64
gen byte a65=age>=65& age <=69
gen byte a70=age>=70& age <=74
gen byte a75=age>=75& age <=79
gen byte a80=age>=80& age <.

*create age-sex-race cell dummies
foreach X of varlist A-W {
	foreach Y of varlist M F {
		foreach Z of varlist a_0-a80{
			gen byte `X'`Y'`Z'=(`X'==1)&(`Y'==1)&(`Z'==1)
			}
		}
	}
*drop original age, sex, and age dummies
drop A C I W M F a_0-a80

**missing age, sex or race
gen byte miss=(race >=5)|(sex ==.)|( age ==.)
egen rowtot=rowtotal( AMa_0-miss)
assert rowtot==1
drop rowtot

total hhweight  
matrix A=e(b)
scalar totalweights=A[1,1]
cap total hhweight  if miss==1
matrix A=e(b)
scalar totalmiss=A[1,1]
scalar nonmissing=1-(totalmiss/totalweights)

foreach X of numlist 9(1)144{
	matrix y200`x'[`X',1]=y200`x'[`X',1]*nonmissing
}
sort uqnr personnr 
collapse (mean) P1-WFa80 (count) hhsize=personnr (sum) hhweight , by(uqnr)

*** Max entropy 
maxentropy  P1-WFa80 , gen(cewgt) prior(hhweight) matrix(y200`x') total(total6_200`x')
replace cewgt=cewgt/hhsize			
sort uqnr
keep uqnr cewgt

sort uqnr   
label var cewgt "post stratified on prov & age-sex-race cells to 200`x' ASSA 2003 estimates"

isid uqnr  
save "$general\output\ghs200`x'_entwgt.dta", replace
}

****end of weights.ghs.do dofile

