************************************************************************************************************
*Created by Nicola Branson, SALDRU, University of Cape Town. Email: nicola.branson@uct.ac.za

*WEIGHTS
*prepare.restrictions.do
*uses ASSA 2003 (1990-2008) data - "ProvOutput_051129.xls" used for province proportions, "assa aids model 2003.xls" used for age-sex-race proportions
	*population totals from full model used in reweighting (totals are slightly different between the the provoutput and full model)
*creates proportion of population in each province cell and in each agecat-sex-race cell for each year
*saves constraint vector for each year in y.dta
************************************************************************************************************
clear
cap set mem 600m
set more off
*filepaths
cd h:\
global ghsfiles "\SALDRU_210409\General Household Survey"
global lfsfiles "\SALDRU_210409\labour force survey 2000-"
global ohsfiles "\SALDRU_210409\October Household Survey 1993-99"
global assafiles "\SALDRU_210409\ASSA\ASSA2003 in stata format created for weights"
global general="\SALDRU_210409\WEIGHTS"
global tempfiles="\SALDRU_210409\WEIGHTS\temp.dta"
************************************************************************************************************
use  "$assafiles\assa2003agesexracetotals.dta", clear

*drop popualtion group totals
drop if cell=="Blackpopulation"| cell=="Colouredpopulation"|cell=="Indianpopulation"|cell=="Whitepopulation"

*Make oldest age category 80+
foreach x in 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 {

replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Blackmales 80 - 84"
drop if cell=="Blackmales 85 +" 
replace cell="Blackmales 80 +" if cell=="Blackmales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Blackfemales 80 - 84"
drop if cell=="Blackfemales 85 +"
replace cell="Blackfemales 80 +" if cell=="Blackfemales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Colouredmales 80 - 84"
drop if cell=="Colouredmales 85 +"
replace cell="Colouredmales 80 +" if cell=="Colouredmales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Colouredfemales 80 - 84"
drop if cell=="Colouredfemales 85 +"
replace cell="Colouredfemales 80 +" if cell=="Colouredfemales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Indianmales 80 - 84"
drop if cell=="Indianmales 85 +"
replace cell="Indianmales 80 +" if cell=="Indianmales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Indianfemales 80 - 84"
drop if cell=="Indianfemales 85 +"
replace cell="Indianfemales 80 +" if cell=="Indianfemales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Whitemales 80 - 84"
drop if cell=="Whitemales 85 +"
replace cell="Whitemales 80 +" if cell=="Whitemales 80 - 84"
replace y`x'=y`x'[_n]+y`x'[_n+1] if cell[_n]=="Whitefemales 80 - 84"
drop if cell=="Whitefemales 85 +"
replace cell="Whitefemales 80 +" if cell=="Whitefemales 80 - 84"
}
*adjust age-sex-race cells to month of the survey
	*OHS & GHS: midyear estimates used
	*LFS: Feb (2000-2002), March (2003-2007) and September
	*e.g. Feb 2001 value = 2000exp(ln(2001/2000)/12*7), September 2001 value = 2001exp(ln(2002/2001)/12*2)
	
foreach x in 2000 2001 2002{
local z=(`x'-1)
gen y2_`x'=(y`z'*exp(ln(y`x'/y`z')/12*7))
label var y2_`x' "Population size, February estimate, ASSA)
}
forvalues x=3/7{
local y=(`x'-1)
gen y3_200`x'=y200`y'*exp(ln(y200`x'/y200`y')/12*8)
label var y3_200`x' "Population size, March estimate, ASSA)
}
forvalues x=0/7{
local z=(`x'+1)
gen y9_200`x'=y200`x'*exp(ln(y200`z'/y200`x')/12*2)
label var y9_200`x' "Population size, September estimate, ASSA)
}
/*to graph trends
reshape long y2_ y3_ y6_ y9_, i(cell) j(year)
expand 3 if year>=2000 & year<=2007
sort  cell year
by cell year: gen n=_n
gen y=y2_ if n==1 & year>=2000 & year<=2002
replace y=y3_ if n==1 & year>=2003 & year<=2007
replace y=y6_ if n==2 & year>=2000 & year<=2007
replace y=y9_ if n==3 & year>=2000 & year<=2007
replace y=y6_ if n==1 & year<2000
replace y=y6_ if n==1 & year==2008
sort  cell
by cell: gen time=_n
sort  cell year n
gen temp=_n if cell!=cell[_n-1]
egen min=min(temp), by(cell)
sort year cell
gen new=min-(_n-1)*34
egen max=max(new), by( cell)
sort max time
*graph example
twoway(line  y time if  max==1, sort)(line  y time if  max==18, sort)(line  y time if  max==2, sort)(line  y time if  max==19, sort)
twoway(line  y year if  max==1 & year>=2000, sort)(line  y year if  max==18 & year>=2000, sort)(line  y year if  max==2 & year>=2000, sort)(line  y year if  max==19 & year>=2000, sort)
twoway(line  y time if  max==1 & year>=2000, sort)(line  y time if  max==18 & year>=2000, sort)(line  y time if  max==2 & year>=2000, sort)(line  y time if  max==19 & year>=2000, sort)
*/
foreach x in 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 {
rename y`x' y6_`x'
label var y6_`x' "Population size, mid year estimate, ASSA)


foreach y in 2 3 6 9{
cap gen y`y'_`x'=.
egen double tot`y'_`x'=sum(y`y'_`x')
scalar total`y'_`x'=tot`y'_`x' 
gen double prop`y'_`x'=y`y'_`x'/tot`y'_`x'
drop tot`y'_`x' y`y'_`x'
rename prop`y'_`x' y`y'_`x'
}
}
save "$tempfiles\asr_y.dta", replace
use "$assafiles\wc.dta", clear
foreach x in ec nc fs kzn nw gt mp lm{
append using "$assafiles\\`x'.dta"
}

*adjust province cells to month of the survey
	*OHS: midyear estimates used
	*LFS: Feb (2000-2002), March (2003-2007) and September
	*e.g. Feb 2001 value = 2000exp(ln(2001/2000)/12*7), September 2001 value = 2001exp(ln(2002/2001)/12*2)
foreach x in 2000 2001 2002{
local z=(`x'-1)
gen y2_`x'=(y`z'*exp(ln(y`x'/y`z')/12*7))
label var y2_`x' "Population size, February estimate, ASSA)
}
forvalues x=3/7{
local y=(`x'-1)
gen y3_200`x'=y200`y'*exp(ln(y200`x'/y200`y')/12*8)
label var y3_200`x' "Population size, March estimate, ASSA)
}
forvalues x=0/7{
local z=(`x'+1)
gen y9_200`x'=y200`x'*exp(ln(y200`z'/y200`x')/12*2)
label var y9_200`x' "Population size, September estimate, ASSA)
}
foreach x in 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 {
rename y`x' y6_`x'
label var y6_`x' "Population size, mid year estimate, ASSA)
}

**calculate totals and construct one dataset
foreach x in 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 {
foreach y in 2 3 6 9{
cap gen y`y'_`x'=.
egen double tot`y'_`x'=sum(y`y'_`x')
gen double prop`y'_`x'=y`y'_`x'/tot`y'_`x'
drop tot`y'_`x' y`y'_`x'
rename prop`y'_`x' y`y'_`x'
}
}
append using "$tempfiles\asr_y.dta"
drop y2_199* y3_199* y9_199*
drop y3_2000 y3_2001  y3_2002
drop y2_2003 y2_2004  y2_2005 y2_2006 y2_2007
drop y2_2008 y3_2008 y9_2008
duplicates drop 
count
assert r(N)==145
save "$tempfiles\y.dta", replace

**end of prepare.restrictions.do
